==> xmlroff-0.3.3.tar.gz: xmlroff-0.3.3/property/fo-property-text-align.c <==
/* Fo
 * fo-property-text-align.c: 'text-align' property
 *
 * Copyright (C) 2001 Sun Microsystems
 *
 * $Id: fo-property-text-align.c,v 1.3 2003/07/02 10:39:38 tonygraham Exp $
 *
 * See Copying for the status of this software.
 */

#include <string.h>
#include "libfo/fo-utils.h"
#include "fo-context.h"
#include "datatype/fo-datatype.h"
#include "property/fo-property-private.h"
#include "property/fo-property-font-size.h"
#include "property/fo-property-text-align.h"

/* Inherited: TRUE */
/* Shorthand: FALSE */
/* text-align */
/* start | center | end | justify | inside | outside | left | right | <string> | inherit */
GType
fo_enum_text_align_get_type (void)
{
  static GType etype = 0;
  if (etype == 0)
    {
      static const GEnumValue values[] = {
        { FO_ENUM_TEXT_ALIGN_START, "FO_ENUM_TEXT_ALIGN_START", "start" },
        { FO_ENUM_TEXT_ALIGN_CENTER, "FO_ENUM_TEXT_ALIGN_CENTER", "center" },
        { FO_ENUM_TEXT_ALIGN_END, "FO_ENUM_TEXT_ALIGN_END", "end" },
        { FO_ENUM_TEXT_ALIGN_JUSTIFY, "FO_ENUM_TEXT_ALIGN_JUSTIFY", "justify" },
        { FO_ENUM_TEXT_ALIGN_INSIDE, "FO_ENUM_TEXT_ALIGN_INSIDE", "inside" },
        { FO_ENUM_TEXT_ALIGN_OUTSIDE, "FO_ENUM_TEXT_ALIGN_OUTSIDE", "outside" },
        { FO_ENUM_TEXT_ALIGN_LEFT, "FO_ENUM_TEXT_ALIGN_LEFT", "left" },
        { FO_ENUM_TEXT_ALIGN_RIGHT, "FO_ENUM_TEXT_ALIGN_RIGHT", "right" },
        { 0, NULL, NULL }
      };
      etype = g_enum_register_static ("FoEnumTextAlign", values);
    }
  return etype;
}

struct _FoPropertyTextAlign
{
  FoProperty parent_instance;
};

struct _FoPropertyTextAlignClass
{
  FoPropertyClass parent_class;
};

static void fo_property_text_align_init         (FoPropertyTextAlign      *property_text_align);
static void fo_property_text_align_base_init   (FoPropertyTextAlignClass *klass);
static void fo_property_text_align_base_finalize   (FoPropertyTextAlignClass *klass);
static void fo_property_text_align_class_init   (FoPropertyTextAlignClass *klass);
static void fo_property_text_align_finalize     (GObject       *object);

static FoDatatype* fo_property_text_align_resolve_enum (const gchar *token,
                                                        FoContext   *context,
                                                        GError     **error);
static FoDatatype* fo_property_text_align_validate (FoDatatype *datatype,
                                                    FoContext  *context,
                                                    GError    **error);

static const gchar class_name[] = "text-align";
static gpointer parent_class;
static FoDatatype *enum_start;
static FoDatatype *enum_center;
static FoDatatype *enum_end;
static FoDatatype *enum_justify;
static FoDatatype *enum_inside;
static FoDatatype *enum_outside;
static FoDatatype *enum_left;
static FoDatatype *enum_right;

/**
 * fo_property_text_align_get_type:
 * 
 * Register the #FoPropertyTextAlign type if not already registered and
 * return its #GType value.
 * 
 * Return value: #GType of #FoPropertyTextAlign.
 **/
GType
fo_property_text_align_get_type (void)
{
  static GType object_type = 0;

  if (!object_type)
    {
      static const GTypeInfo object_info =
      {
        sizeof (FoPropertyTextAlignClass),
        (GBaseInitFunc) fo_property_text_align_base_init,
        (GBaseFinalizeFunc) fo_property_text_align_base_finalize,
        (GClassInitFunc) fo_property_text_align_class_init,
        NULL,           /* class_finalize */
        NULL,           /* class_data */
        sizeof (FoPropertyTextAlign),
        0,              /* n_preallocs */
        (GInstanceInitFunc) fo_property_text_align_init,
	NULL		/* value_table */
      };

      object_type = g_type_register_static (FO_TYPE_PROPERTY,
                                            class_name,
                                            &object_info, 0);
    }

  return object_type;
}

/**
 * fo_property_text_align_init:
 * @text_align: #FoPropertyTextAlign object to initialise.
 * 
 * Implements #GInstanceInitFunc for #FoPropertyTextAlign.
 **/
void
fo_property_text_align_init (FoPropertyTextAlign *text_align)
{
  FO_PROPERTY (text_align)->value =
    g_object_ref (enum_start);
}

/**
 * fo_property_text_align_base_init:
 * @klass: #FoPropertyTextAlignClass object to initialise.
 * 
 * Implements #GBaseInitFunc for #FoPropertyTextAlignClass.
 **/
void
fo_property_text_align_base_init (FoPropertyTextAlignClass *klass)
{
  enum_start =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_START,
                  NULL);
  enum_center =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_CENTER,
                  NULL);
  enum_end =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_END,
                  NULL);
  enum_justify =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_JUSTIFY,
                  NULL);
  enum_inside =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_INSIDE,
                  NULL);
  enum_outside =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_OUTSIDE,
                  NULL);
  enum_left =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_LEFT,
                  NULL);
  enum_right =
    g_object_new (FO_TYPE_ENUM,
                  "enum-class",
                  g_type_class_ref (FO_TYPE_ENUM_TEXT_ALIGN),
                  "value",
                  FO_ENUM_TEXT_ALIGN_RIGHT,
                  NULL);
}

/**
 * fo_property_text_align_base_finalize:
 * @klass: #FoPropertyTextAlignClass object to finalise.
 * 
 * Implements #GBaseFinalizeFunc for #FoPropertyTextAlignClass.
 **/
void
fo_property_text_align_base_finalize (FoPropertyTextAlignClass *klass)
{
  g_object_unref (enum_start);
  g_object_unref (enum_center);
  g_object_unref (enum_end);
  g_object_unref (enum_justify);
  g_object_unref (enum_inside);
  g_object_unref (enum_outside);
  g_object_unref (enum_left);
  g_object_unref (enum_right);
}

/**
 * fo_property_text_align_class_init:
 * @klass: #FoPropertyTextAlignClass object to initialise.
 * 
 * Implements #GClassInitFunc for #FoPropertyTextAlignClass.
 **/
void
fo_property_text_align_class_init (FoPropertyTextAlignClass *klass)
{
  GObjectClass *object_class = G_OBJECT_CLASS (klass);
  FoPropertyClass *property_class = FO_PROPERTY_CLASS (klass);

  parent_class = g_type_class_peek_parent (klass);

  object_class->finalize = fo_property_text_align_finalize;

  property_class->is_inherited = TRUE;
  property_class->is_shorthand = FALSE;
  property_class->resolve_enum =
    fo_property_text_align_resolve_enum;
  property_class->validate =
    fo_property_text_align_validate;
  property_class->get_initial =
    fo_property_text_align_get_initial;
}

/**
 * fo_property_text_align_finalize:
 * @object: #FoPropertyTextAlign object to finalize.
 * 
 * Implements #GObjectFinalizeFunc for #FoPropertyTextAlign.
 **/
void
fo_property_text_align_finalize (GObject *object)
{
  FoPropertyTextAlign *text_align;

  text_align = FO_PROPERTY_TEXT_ALIGN (object);

  G_OBJECT_CLASS (parent_class)->finalize (object);
}


/**
 * fo_property_text_align_new:
 * 
 * Creates a new #FoPropertyTextAlign initialized to default value.
 * 
 * Return value: the new #FoPropertyTextAlign.
 **/
FoProperty*
fo_property_text_align_new (void)
{
  FoProperty* text_align;

  text_align =
    FO_PROPERTY (g_object_new (fo_property_text_align_get_type (),
                               NULL));

  return text_align;
}

/**
 * fo_property_text_align_resolve_enum:
 * @token:   Token from the XML attribute value to be evaluated as an
 *           enumeration token.
 * @context: #FoContext object from which to possibly inherit values.
 * @error:   Information about any error that has occurred.
 * 
 * Compare @token against the enumeration tokens that are valid for the
 * current FO property.  If @token is valid, returns either an #FoEnum datatype
 * representing the enumeration token or a different datatype representing
 * the enumeration token's resolved value.  If @token is not valid,
 * sets @error and returns NULL.
 * 
 * Return value: Resolved enumeration value or NULL.
 **/
FoDatatype*
fo_property_text_align_resolve_enum (const gchar *token,
                                     FoContext   *context,
                                     GError     **error)
{
  g_return_val_if_fail (token != NULL, NULL);
  g_return_val_if_fail (FO_IS_CONTEXT (context), NULL);
  g_return_val_if_fail (error == NULL || *error == NULL, NULL);

  if (strcmp (token, "start") == 0)
    {
      return g_object_ref (enum_start);
    }
  else if (strcmp (token, "center") == 0)
    {
      return g_object_ref (enum_center);
    }
  else if (strcmp (token, "end") == 0)
    {
      return g_object_ref (enum_end);
    }
  else if (strcmp (token, "justify") == 0)
    {
      return g_object_ref (enum_justify);
    }
  else if (strcmp (token, "inside") == 0)
    {
      return g_object_ref (enum_inside);
    }
  else if (strcmp (token, "outside") == 0)
    {
      return g_object_ref (enum_outside);
    }
  else if (strcmp (token, "left") == 0)
    {
      return g_object_ref (enum_left);
    }
  else if (strcmp (token, "right") == 0)
    {
      return g_object_ref (enum_right);
    }
  else
    {
      g_set_error (error,
		   FO_FO_ERROR,
		   FO_FO_ERROR_ENUMERATION_TOKEN,
		   _(fo_fo_error_messages[FO_FO_ERROR_ENUMERATION_TOKEN]),
		   class_name,
		   token);
      return NULL;
    }
}

/**
 * fo_property_text_align_validate:
 * @datatype: #FoDatatype to be validated against allowed datatypes and
 *            values for current property.
 * @context:  #FoContext object from which to possibly inherit values.
 * @error:    Information about any error that has occurred.
 * 
 * Validates @datatype against allowed values.  Returns @datatype, a
 * replacement datatype value, or NULL if validation failed.
 * 
 * Return value: Valid datatype value or NULL.
 **/
FoDatatype*
fo_property_text_align_validate (FoDatatype *datatype,
                                 FoContext  *context,
                                 GError    **error)
{
  FoDatatype *new_datatype;
  GError     *tmp_error = NULL;
  gchar      *token;

  g_return_val_if_fail (datatype != NULL, NULL);
  g_return_val_if_fail (FO_IS_DATATYPE (datatype), NULL);
  g_return_val_if_fail (context != NULL, NULL);
  g_return_val_if_fail (FO_IS_CONTEXT (context), NULL);
  g_return_val_if_fail (error == NULL || *error == NULL, NULL);

  if (FO_IS_ENUM (datatype))
    {
      if ((G_ENUM_CLASS_TYPE (fo_enum_get_enum_class (datatype))
           == FO_TYPE_ENUM_TEXT_ALIGN) &&
	  (g_enum_get_value (fo_enum_get_enum_class (datatype),
			     fo_enum_get_value (datatype)) != NULL))
	{
	  return datatype;
	}
      else
	{
	  gchar *datatype_sprintf = fo_object_sprintf (datatype);

	  g_set_error (error,
		       FO_FO_ERROR,
		       FO_FO_ERROR_DATATYPE,
		       _(fo_fo_error_messages[FO_FO_ERROR_DATATYPE]),
		       class_name,
		       datatype_sprintf,
		       g_type_name (G_TYPE_FROM_INSTANCE (datatype)));

	  g_object_unref (datatype);

	  g_free (datatype_sprintf);

	  return NULL;
	}
    }
  else if (FO_IS_STRING (datatype))
    {
      token = fo_string_get_value (datatype);

      new_datatype =
        fo_property_text_align_resolve_enum (token, context, &tmp_error);

      g_object_unref (datatype);

      if (tmp_error != NULL)
	{
	  g_propagate_error (error, tmp_error);
	  return NULL;
	}

      return new_datatype;
    }
  else if (FO_IS_NAME (datatype))
    {
      token = fo_name_get_value (datatype);

      new_datatype =
        fo_property_text_align_resolve_enum (token, context, &tmp_error);

      g_object_unref (datatype);

      if (tmp_error != NULL)
	{
	  g_propagate_error (error, tmp_error);
	  return NULL;
	}

      return new_datatype;
    }
  else if (FO_IS_STRING (datatype))
    {
      return datatype;
    }
  else
    {
      gchar *datatype_sprintf = fo_object_sprintf (datatype);

      g_set_error (error,
		   FO_FO_ERROR,
		   FO_FO_ERROR_DATATYPE,
		   _(fo_fo_error_messages[FO_FO_ERROR_DATATYPE]),
		   class_name,
		   datatype_sprintf,
		   g_type_name (G_TYPE_FROM_INSTANCE (datatype)));

      g_object_unref (datatype);

      g_free (datatype_sprintf);

      return NULL;
    }
}

/**
 * fo_property_text_align_get_initial:
 * 
 * Get an instance of the property with the correct initial value.
 * 
 * Return value: An instance of the property.
 **/
FoProperty*
fo_property_text_align_get_initial (void)
{
  static FoProperty *text_align = NULL;

  if (text_align == NULL)
    {
      text_align = fo_property_text_align_new ();
    }

  return text_align;
}

==> xmlroff-0.5.0.tar.gz: xmlroff-0.5.0/property/fo-property-text-align.c <==
/* Fo
 * fo-property-text-align.c: 'text-align' property
 *
 * Copyright (C) 2001-2005 Sun Microsystems
 *
 * $Id: fo-property-text-align.c,v 1.4 2005/08/18 09:46:05 tonygraham Exp $
 *
 * See Copying for the status of this software.
 */

#include <string.h>
#include "libfo/fo-utils.h"
#include "fo-context.h"
#include "datatype/fo-datatype.h"
#include "property/fo-property-private.h"
#include "property/fo-property-font-size.h"
#include "property/fo-property-text-align.h"

/* text-align */
/* Inherited: TRUE */
/* Shorthand: FALSE */
/* start | center | end | justify | inside | outside | left | right | <string> | inherit */
/* Initial value: start */

struct _FoPropertyTextAlign
{
  FoProperty parent_instance;
};

struct _FoPropertyTextAlignClass
{
  FoPropertyClass parent_class;
};

static void fo_property_text_align_init         (FoPropertyTextAlign      *property_text_align);
static void fo_property_text_align_class_init   (FoPropertyTextAlignClass *klass);
static void fo_property_text_align_finalize     (GObject       *object);

static FoDatatype * fo_property_text_align_resolve_enum (const gchar *token,
                                                          FoContext   *context,
                                                          GError     **error);
static FoDatatype * fo_property_text_align_validate (FoDatatype *datatype,
                                                     FoContext  *context,
                                                     GError    **error);

static const gchar class_name[] = "text-align";
static gpointer parent_class;

/**
 * fo_property_text_align_get_type:
 * 
 * Register the #FoPropertyTextAlign type if not already registered and
 * return its #GType value.
 * 
 * Return value: #GType of #FoPropertyTextAlign.
 **/
GType
fo_property_text_align_get_type (void)
{
  static GType object_type = 0;

  if (!object_type)
    {
      static const GTypeInfo object_info =
      {
        sizeof (FoPropertyTextAlignClass),
        NULL,           /* base_init */
        NULL,           /* base_finalize */
        (GClassInitFunc) fo_property_text_align_class_init,
        NULL,           /* class_finalize */
        NULL,           /* class_data */
        sizeof (FoPropertyTextAlign),
        0,              /* n_preallocs */
        (GInstanceInitFunc) fo_property_text_align_init,
	NULL		/* value_table */
      };

      object_type = g_type_register_static (FO_TYPE_PROPERTY,
                                            class_name,
                                            &object_info, 0);
    }

  return object_type;
}

/**
 * fo_property_text_align_init:
 * @text_align: #FoPropertyTextAlign object to initialise.
 * 
 * Implements #GInstanceInitFunc for #FoPropertyTextAlign.
 **/
void
fo_property_text_align_init (FoPropertyTextAlign *text_align)
{
  FO_PROPERTY (text_align)->value =
    g_object_ref (fo_enum_get_enum_by_nick ("start"));
}

/**
 * fo_property_text_align_class_init:
 * @klass: #FoPropertyTextAlignClass object to initialise.
 * 
 * Implements #GClassInitFunc for #FoPropertyTextAlignClass.
 **/
void
fo_property_text_align_class_init (FoPropertyTextAlignClass *klass)
{
  GObjectClass *object_class = G_OBJECT_CLASS (klass);
  FoPropertyClass *property_class = FO_PROPERTY_CLASS (klass);

  parent_class = g_type_class_peek_parent (klass);

  object_class->finalize = fo_property_text_align_finalize;

  property_class->is_inherited = TRUE;
  property_class->is_shorthand = FALSE;
  property_class->resolve_enum =
    fo_property_text_align_resolve_enum;
  property_class->validate =
    fo_property_text_align_validate;
  property_class->get_initial =
    fo_property_text_align_get_initial;
}

/**
 * fo_property_text_align_finalize:
 * @object: #FoPropertyTextAlign object to finalize.
 * 
 * Implements #GObjectFinalizeFunc for #FoPropertyTextAlign.
 **/
void
fo_property_text_align_finalize (GObject *object)
{
  FoPropertyTextAlign *text_align;

  text_align = FO_PROPERTY_TEXT_ALIGN (object);

  G_OBJECT_CLASS (parent_class)->finalize (object);
}


/**
 * fo_property_text_align_new:
 * 
 * Creates a new #FoPropertyTextAlign initialized to default value.
 * 
 * Return value: the new #FoPropertyTextAlign.
 **/
FoProperty*
fo_property_text_align_new (void)
{
  FoProperty* text_align;

  text_align =
    FO_PROPERTY (g_object_new (fo_property_text_align_get_type (),
                               NULL));

  return text_align;
}

/**
 * fo_property_text_align_resolve_enum:
 * @token:   Token from the XML attribute value to be evaluated as an
 *           enumeration token.
 * @context: #FoContext object from which to possibly inherit values.
 * @error:   Information about any error that has occurred.
 * 
 * Compare @token against the enumeration tokens that are valid for the
 * current FO property.  If @token is valid, returns either an #FoEnum datatype
 * representing the enumeration token or a different datatype representing
 * the enumeration token's resolved value.  If @token is not valid,
 * sets @error and returns NULL.
 * 
 * Return value: Resolved enumeration value or NULL.
 **/
FoDatatype*
fo_property_text_align_resolve_enum (const gchar *token,
                                     FoContext   *context,
                                     GError     **error)
{
  g_return_val_if_fail (token != NULL, NULL);
  g_return_val_if_fail (FO_IS_CONTEXT (context), NULL);
  g_return_val_if_fail (error == NULL || *error == NULL, NULL);

  if ((strcmp (token, "start") == 0) ||
      (strcmp (token, "center") == 0) ||
      (strcmp (token, "end") == 0) ||
      (strcmp (token, "justify") == 0) ||
      (strcmp (token, "inside") == 0) ||
      (strcmp (token, "outside") == 0) ||
      (strcmp (token, "left") == 0) ||
      (strcmp (token, "right") == 0))
    {
      return g_object_ref (fo_enum_get_enum_by_nick (token));
    }
  else
    {
      g_set_error (error,
		   FO_FO_ERROR,
		   FO_FO_ERROR_ENUMERATION_TOKEN,
		   _(fo_fo_error_messages[FO_FO_ERROR_ENUMERATION_TOKEN]),
		   class_name,
		   token);
      return NULL;
    }
}

/**
 * fo_property_text_align_validate:
 * @datatype: #FoDatatype to be validated against allowed datatypes and
 *            values for current property.
 * @context:  #FoContext object from which to possibly inherit values.
 * @error:    Information about any error that has occurred.
 * 
 * Validates @datatype against allowed values.  Returns @datatype, a
 * replacement datatype value, or NULL if validation failed.
 * 
 * Return value: Valid datatype value or NULL.
 **/
FoDatatype*
fo_property_text_align_validate (FoDatatype *datatype,
                                 FoContext  *context,
                                 GError    **error)
{
  FoDatatype *new_datatype;
  GError     *tmp_error = NULL;
  gchar      *token;

  g_return_val_if_fail (datatype != NULL, NULL);
  g_return_val_if_fail (FO_IS_DATATYPE (datatype), NULL);
  g_return_val_if_fail (context != NULL, NULL);
  g_return_val_if_fail (FO_IS_CONTEXT (context), NULL);
  g_return_val_if_fail (error == NULL || *error == NULL, NULL);

  if (FO_IS_ENUM (datatype))
    {
      FoEnumEnum value = fo_enum_get_value (datatype);

      if ((value == FO_ENUM_ENUM_START) ||
          (value == FO_ENUM_ENUM_CENTER) ||
          (value == FO_ENUM_ENUM_END) ||
          (value == FO_ENUM_ENUM_JUSTIFY) ||
          (value == FO_ENUM_ENUM_INSIDE) ||
          (value == FO_ENUM_ENUM_OUTSIDE) ||
          (value == FO_ENUM_ENUM_LEFT) ||
          (value == FO_ENUM_ENUM_RIGHT))
	{
	  return datatype;
	}
      else
	{
	  gchar *datatype_sprintf = fo_object_sprintf (datatype);

	  g_set_error (error,
		       FO_FO_ERROR,
		       FO_FO_ERROR_ENUMERATION_TOKEN,
		       _(fo_fo_error_messages[FO_FO_ERROR_ENUMERATION_TOKEN]),
		       class_name,
		       datatype_sprintf,
		       g_type_name (G_TYPE_FROM_INSTANCE (datatype)));

	  g_object_unref (datatype);

	  g_free (datatype_sprintf);

	  return NULL;
	}
    }
  else if (FO_IS_STRING (datatype))
    {
      token = fo_string_get_value (datatype);

      new_datatype =
        fo_property_text_align_resolve_enum (token, context, &tmp_error);

      g_object_unref (datatype);

      fo_propagate_and_return_val_if_error (error, tmp_error, NULL);

      return new_datatype;
    }
  else if (FO_IS_NAME (datatype))
    {
      token = fo_name_get_value (datatype);

      new_datatype =
        fo_property_text_align_resolve_enum (token, context, &tmp_error);

      g_object_unref (datatype);

      fo_propagate_and_return_val_if_error (error, tmp_error, NULL);

      return new_datatype;
    }
  else if (FO_IS_STRING (datatype))
    {
      return datatype;
    }
  else
    {
      gchar *datatype_sprintf = fo_object_sprintf (datatype);

      g_set_error (error,
		   FO_FO_ERROR,
		   FO_FO_ERROR_DATATYPE,
		   _(fo_fo_error_messages[FO_FO_ERROR_DATATYPE]),
		   class_name,
		   datatype_sprintf,
		   g_type_name (G_TYPE_FROM_INSTANCE (datatype)));

      g_object_unref (datatype);

      g_free (datatype_sprintf);

      return NULL;
    }
}

/**
 * fo_property_text_align_get_initial:
 * 
 * Get an instance of the property with the correct initial value.
 * 
 * Return value: An instance of the property.
 **/
FoProperty*
fo_property_text_align_get_initial (void)
{
  static FoProperty *text_align = NULL;

  if (text_align == NULL)
    {
      text_align =
	fo_property_text_align_new ();
    }

  return text_align;
}
